#!/bin/bash

ROOT_DIR=`dirname $0`

# Get a list of directories (ie, packages) in this directory
PKGS=`ls -lh $ROOT_DIR | grep -E '^d' | awk '{ print $9 }'`

source /etc/makepkg.conf

# Check namcap is available
NAMCAP=`which namcap`
if [ ! -x "$NAMCAP" ] ; then
	echo "namcap not found; aborting"
	exit 1
fi

VERBOSE=false

# Loop through each package
for PKG in $PKGS ; do
	if [ -r "$ROOT_DIR/$PKG/PKGBUILD" ] ; then
		echo "Cleaning up $PKG"
		
		[ $VERBOSE = true ] && echo "   Inspecting with namcap..."
		$NAMCAP --exclude=fileownership,tags $ROOT_DIR/$PKG/PKGBUILD
		
		[ $VERBOSE = true ] && echo -n "   Removing build files... "
		rm -Rf $ROOT_DIR/$PKG/pkg
		if [ "${PKG:(-4)}" != "-svn" ] ; then
			[ $VERBOSE = true ] && echo "Removing src dir"
			rm -Rf $ROOT_DIR/$PKG/src	
		fi

		source $ROOT_DIR/$PKG/PKGBUILD
		for SRC in ${source[@]} ; do
			if [ "${SRC:0:7}" = 'http://' -o "${SRC:0:6}" = 'ftp://' ] ; then
				FNAME=`basename $SRC`
				if [ -e "$ROOT_DIR/$PKG/$FNAME" ] ; then
					[ $VERBOSE = true ] && echo "Removing $FNAME"
					rm -f "$ROOT_DIR/$PKG/$FNAME"
				fi
			fi
		done
		[ $VERBOSE = true ] && echo "Done"
		
		BUILT=`find $ROOT_DIR/$PKG -maxdepth 1 -name \*.pkg.tar.gz -o -name \*.src.tar.gz`
		if [ ! -z "$BUILT" ] ; then
			[ $VERBOSE = true ] && echo -n "   Moving built packages to $PKG/built... "
			if [ ! -d "$ROOT_DIR/$PKG/built" ] ; then
				mkdir "$ROOT_DIR/$PKG/built"
			fi
			for F in $BUILT ; do
				[ $VERBOSE = true ] && echo "     $F to $PKG/built/$F"
				mv $F $ROOT_DIR/$PKG/built/
			done
			[ $VERBOSE = true ] && echo "Done"
		fi
	
		[ $VERBOSE = true ] && echo -n "   Fixing permissions... "
		chmod 640 $ROOT_DIR/$PKG/PKGBUILD
		chmod 750 $ROOT_DIR/$PKG
		[ $VERBOSE = true ] && echo "Done"
	else
		echo "$PKG doesn't appear to be a package directory; couldn't locate a PKGBUILD file; skipping"
	fi
done

# Cleanup partially downloaded files
echo "Cleaning up partially downloaded files..."
find $ROOT_DIR/ -name \*.part -exec rm -f {} \;

exit 0
